/**
 * Copyright (C) 2009-2010 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SETTINGS_H
#define SETTINGS_H

#include <glib.h>

typedef struct _WkSettings
{
    gboolean  can_end_session;
    gboolean  fullscreen;
    gboolean  with_clear;
    gboolean  with_timer;
    gboolean  can_access_fs;
    gint      max_history;
    gint      max_windows;
    gchar    *default_url;
    guint     after_web_session;

    gchar *cookies_db;

    guint  list_mode;
    GList *list;

    gboolean start_with_session;
    gboolean hide_toolbar;
    gchar   *post_session_uri;
    guint    post_session_uri_time;
    gint     start_with_time;
    gchar   *prestart;

    GList   *slideshow_views;
    gboolean slideshow_hide_pointer;
    gboolean slideshow_mute;

    GHashTable *mime_associations;

    gchar *admin_passwd;

    gchar *tmpdir_name;
} WkSettings;

enum
{
    LIST_MODE_NONE = 0,
    LIST_MODE_WHITELIST,
    LIST_MODE_BLACKLIST
};

enum
{
    AFTER_WEB_SESSION_HOMEPAGE = 0,
    AFTER_WEB_SESSION_SLIDESHOW,
    AFTER_WEB_SESSION_SESSION
};

/* default settings */
#define PREF_DEFAULT_URL "http://linutop.com"
#define PREF_CAN_END_SESSION FALSE
#define PREF_FULLSCREEN TRUE
#define PREF_MAX_HISTORY 50
#define PREF_MAX_WINDOWS 0
#define PREF_WITH_TIMER FALSE
#define PREF_WITH_CLEAR TRUE
#define PREF_CAN_QUIT FALSE
#define PREF_CAN_ACCESS_FS FALSE
#define PREF_LIST_MODE LIST_MODE_NONE
#define PREF_LIST_USE_REGEX FALSE
#define PREF_START_WITH_SESSION TRUE
#define PREF_HIDE_TOOLBAR FALSE
#define PREF_START_WITH_TIME 300
#define PREF_POST_SESSION_URI_TIME 10
#define PREF_SLIDESHOW_HIDE_POINTER TRUE
#define PREF_SLIDESHOW_MUTE TRUE
#define PREF_DEFAULT_AFTER_WEB_SESSION AFTER_WEB_SESSION_SESSION

void wk_settings_load_from_data (WkSettings **settings,
                                 const gchar *data);
void wk_settings_load_from_uri  (WkSettings **settings,
                                 const gchar *uri);

void wk_settings_set_slideshow_from_contents (WkSettings  *settings,
                                              const gchar *contents);

void wk_settings_free_slideshow (WkSettings *settings);
void wk_settings_free           (WkSettings *settings);

GList *wk_settings_expand_playlist (WkSettings *settings);

#endif /* !SETTINGS_H */
